Class: Resolv::DNS::Resource::LOC
- Inherits:
-
Resource
- Object
- Resource
- Resolv::DNS::Resource::LOC
- Defined in:
- lib/resolv.rb
Overview
Location resource
Constant Summary collapse
- TypeValue =
:nodoc:
29
Instance Attribute Summary collapse
-
#altitude ⇒ Object
readonly
The altitude of the LOC above a reference sphere whose surface sits 100km below the WGS84 spheroid in centimeters as an unsigned 32bit integer.
-
#hprecision ⇒ Object
readonly
The horizontal precision using ssize type values in meters using scientific notation as 2 integers of XeY for precision use value/2 e.g.
-
#latitude ⇒ Object
readonly
The latitude for this LOC where 2**31 is the equator in thousandths of an arc second as an unsigned 32bit integer.
-
#longitude ⇒ Object
readonly
The longitude for this LOC where 2**31 is the prime meridian in thousandths of an arc second as an unsigned 32bit integer.
-
#ssize ⇒ Object
readonly
The spherical size of this LOC in meters using scientific notation as 2 integers of XeY.
-
#version ⇒ Object
readonly
Returns the version value for this LOC record which should always be 00.
-
#vprecision ⇒ Object
readonly
The vertical precision using ssize type values in meters using scientific notation as 2 integers of XeY for precision use value/2 e.g.
Class Method Summary collapse
-
.decode_rdata(msg) ⇒ Object
:nodoc:.
Instance Method Summary collapse
-
#encode_rdata(msg) ⇒ Object
:nodoc:.
-
#initialize(version, ssize, hprecision, vprecision, latitude, longitude, altitude) ⇒ LOC
constructor
A new instance of LOC.
Constructor Details
#initialize(version, ssize, hprecision, vprecision, latitude, longitude, altitude) ⇒ LOC
Returns a new instance of LOC.
2678 2679 2680 2681 2682 2683 2684 2685 2686 |
# File 'lib/resolv.rb', line 2678 def initialize(version, ssize, hprecision, vprecision, latitude, longitude, altitude) @version = version @ssize = Resolv::LOC::Size.create(ssize) @hprecision = Resolv::LOC::Size.create(hprecision) @vprecision = Resolv::LOC::Size.create(vprecision) @latitude = Resolv::LOC::Coord.create(latitude) @longitude = Resolv::LOC::Coord.create(longitude) @altitude = Resolv::LOC::Alt.create(altitude) end |
Instance Attribute Details
#altitude ⇒ Object (readonly)
The altitude of the LOC above a reference sphere whose surface sits 100km below the WGS84 spheroid in centimeters as an unsigned 32bit integer
2729 2730 2731 |
# File 'lib/resolv.rb', line 2729 def altitude @altitude end |
#hprecision ⇒ Object (readonly)
The horizontal precision using ssize type values in meters using scientific notation as 2 integers of XeY for precision use value/2 e.g. 2m = +/-1m
2704 2705 2706 |
# File 'lib/resolv.rb', line 2704 def hprecision @hprecision end |
#latitude ⇒ Object (readonly)
The latitude for this LOC where 2**31 is the equator in thousandths of an arc second as an unsigned 32bit integer
2717 2718 2719 |
# File 'lib/resolv.rb', line 2717 def latitude @latitude end |
#longitude ⇒ Object (readonly)
The longitude for this LOC where 2**31 is the prime meridian in thousandths of an arc second as an unsigned 32bit integer
2723 2724 2725 |
# File 'lib/resolv.rb', line 2723 def longitude @longitude end |
#ssize ⇒ Object (readonly)
The spherical size of this LOC in meters using scientific notation as 2 integers of XeY
2697 2698 2699 |
# File 'lib/resolv.rb', line 2697 def ssize @ssize end |
#version ⇒ Object (readonly)
Returns the version value for this LOC record which should always be 00
2691 2692 2693 |
# File 'lib/resolv.rb', line 2691 def version @version end |
#vprecision ⇒ Object (readonly)
The vertical precision using ssize type values in meters using scientific notation as 2 integers of XeY for precision use value/2 e.g. 2m = +/-1m
2711 2712 2713 |
# File 'lib/resolv.rb', line 2711 def vprecision @vprecision end |
Class Method Details
.decode_rdata(msg) ⇒ Object
:nodoc:
2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 2753 2754 2755 2756 2757 2758 |
# File 'lib/resolv.rb', line 2741 def self.decode_rdata(msg) # :nodoc: version = msg.get_bytes(1) ssize = msg.get_bytes(1) hprecision = msg.get_bytes(1) vprecision = msg.get_bytes(1) latitude = msg.get_bytes(4) longitude = msg.get_bytes(4) altitude = msg.get_bytes(4) return self.new( version, Resolv::LOC::Size.new(ssize), Resolv::LOC::Size.new(hprecision), Resolv::LOC::Size.new(vprecision), Resolv::LOC::Coord.new(latitude,"lat"), Resolv::LOC::Coord.new(longitude,"lon"), Resolv::LOC::Alt.new(altitude) ) end |
Instance Method Details
#encode_rdata(msg) ⇒ Object
:nodoc:
2731 2732 2733 2734 2735 2736 2737 2738 2739 |
# File 'lib/resolv.rb', line 2731 def encode_rdata(msg) # :nodoc: msg.put_bytes(@version) msg.put_bytes(@ssize.scalar) msg.put_bytes(@hprecision.scalar) msg.put_bytes(@vprecision.scalar) msg.put_bytes(@latitude.coordinates) msg.put_bytes(@longitude.coordinates) msg.put_bytes(@altitude.altitude) end |