Class: Resolv::DNS::Resource::MINFO

Inherits:
Resource
  • Object
show all
Defined in:
lib/resolv.rb

Overview

Mailing list or mailbox information.

Constant Summary collapse

TypeValue =

:nodoc:

14

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(rmailbx, emailbx) ⇒ MINFO

Returns a new instance of MINFO.



2476
2477
2478
2479
# File 'lib/resolv.rb', line 2476

def initialize(rmailbx, emailbx)
  @rmailbx = rmailbx
  @emailbx = emailbx
end

Instance Attribute Details

#emailbxObject (readonly)

Mailbox to use for error messages related to the mail list or mailbox.



2489
2490
2491
# File 'lib/resolv.rb', line 2489

def emailbx
  @emailbx
end

#rmailbxObject (readonly)

Domain name responsible for this mail list or mailbox.



2484
2485
2486
# File 'lib/resolv.rb', line 2484

def rmailbx
  @rmailbx
end

Class Method Details

.decode_rdata(msg) ⇒ Object

:nodoc:



2496
2497
2498
2499
2500
# File 'lib/resolv.rb', line 2496

def self.decode_rdata(msg) # :nodoc:
  rmailbx = msg.get_string
  emailbx = msg.get_string
  return self.new(rmailbx, emailbx)
end

Instance Method Details

#encode_rdata(msg) ⇒ Object

:nodoc:



2491
2492
2493
2494
# File 'lib/resolv.rb', line 2491

def encode_rdata(msg) # :nodoc:
  msg.put_name(@rmailbx)
  msg.put_name(@emailbx)
end