Class: Resolv::DNS::Resource::MINFO
- Inherits:
-
Resource
- Object
- Resource
- Resolv::DNS::Resource::MINFO
- Defined in:
- lib/resolv.rb
Overview
Mailing list or mailbox information.
Constant Summary collapse
- TypeValue =
:nodoc:
14
Instance Attribute Summary collapse
-
#emailbx ⇒ Object
readonly
Mailbox to use for error messages related to the mail list or mailbox.
-
#rmailbx ⇒ Object
readonly
Domain name responsible for this mail list or mailbox.
Class Method Summary collapse
-
.decode_rdata(msg) ⇒ Object
:nodoc:.
Instance Method Summary collapse
-
#encode_rdata(msg) ⇒ Object
:nodoc:.
-
#initialize(rmailbx, emailbx) ⇒ MINFO
constructor
A new instance of MINFO.
Constructor Details
#initialize(rmailbx, emailbx) ⇒ MINFO
Returns a new instance of MINFO.
2573 2574 2575 2576 |
# File 'lib/resolv.rb', line 2573 def initialize(rmailbx, emailbx) @rmailbx = rmailbx @emailbx = emailbx end |
Instance Attribute Details
#emailbx ⇒ Object (readonly)
Mailbox to use for error messages related to the mail list or mailbox.
2586 2587 2588 |
# File 'lib/resolv.rb', line 2586 def emailbx @emailbx end |
#rmailbx ⇒ Object (readonly)
Domain name responsible for this mail list or mailbox.
2581 2582 2583 |
# File 'lib/resolv.rb', line 2581 def rmailbx @rmailbx end |
Class Method Details
.decode_rdata(msg) ⇒ Object
:nodoc:
2593 2594 2595 2596 2597 |
# File 'lib/resolv.rb', line 2593 def self.decode_rdata(msg) # :nodoc: rmailbx = msg.get_string emailbx = msg.get_string return self.new(rmailbx, emailbx) end |
Instance Method Details
#encode_rdata(msg) ⇒ Object
:nodoc:
2588 2589 2590 2591 |
# File 'lib/resolv.rb', line 2588 def encode_rdata(msg) # :nodoc: msg.put_name(@rmailbx) msg.put_name(@emailbx) end |